#
# spec file for package hp-drive-guard
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define polkitdir	%{_datadir}/polkit-1/actions

Name:           hp-drive-guard
Version:        0.3.12
Release:        28.2
Summary:        HP DriveGuard for SUSE
License:        GPL-2.0-or-later
Group:          Hardware/Mobile
Source:         hp-drive-guard-%{version}.tar.bz2
Source1:        hp-drive-guard.service
Patch1:         0001-Fix-misc-compile-warnings.patch
Patch2:         0002-Fix-build-with-the-new-libnotify.patch
Patch3:         use-new-polkit.diff
Patch4:         use-gtk3.diff
Patch5:         hp-drive-guard-gcc14-fix.patch
URL:            http://www.gnome.org
BuildRequires:  dbus-1-glib-devel
BuildRequires:  fdupes
BuildRequires:  gnome-common
BuildRequires:  gtk3-devel
BuildRequires:  intltool
BuildRequires:  libnotify-devel
BuildRequires:  libupower-glib-devel
BuildRequires:  libxslt
BuildRequires:  polkit-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(systemd)
%{?systemd_requires}

%description
HP DriveGuard for SUSE. Can protect hard disks on HP laptops by
spinning them down when shaking or free-fall is detected.

%lang_package

%prep
%autosetup -p1
%define pm_method	upower
%define user_setup	--enable-user-setup

%build
autoreconf -f -i
%configure --with-pm=%{pm_method} %user_setup \
	--disable-schemas-install \
	--disable-scrollkeeper
%{?make_build:%make_build}
%{?!make_build:make %{?_smp_mflags}}

%install
%make_install
mkdir -p %{buildroot}/%{_unitdir}
install -cm 0644 %{S:1} %{buildroot}/%{_unitdir}/hp-drive-guard.service
# do not ship the init.d script on a systemd setup
rm %{buildroot}%{_sysconfdir}/init.d/hp-drive-guard
%find_lang %{name}
%fdupes %buildroot/%_prefix

%pre
%service_add_pre hp-drive-guard.service

%post
%service_add_post hp-drive-guard.service

%preun
%service_del_preun hp-drive-guard.service

%postun
%service_del_postun hp-drive-guard.service

%files -f %{name}.lang
%doc AUTHORS ChangeLog NEWS README
%license COPYING
%config(noreplace) /etc/*.conf
%{_bindir}/*
%{_sbindir}/*
%{_libexecdir}/hp-drive-guard
%{_sysconfdir}/xdg/autostart/hp-drive-guard-client.desktop
%{_sysconfdir}/dbus-1/system.d/hp-drive-guard-dbus.conf
%{polkitdir}/*
%{_unitdir}/hp-drive-guard.service

%changelog
* Tue Aug 27 2024 Jan Engelhardt <jengelh@inai.de>
- Remove build instructions for old unsupported SUSE releases
* Fri Aug 23 2024 Takashi Iwai <tiwai@suse.com>
- Fix the build with gcc14:
  hp-drive-guard-gcc14-fix.patch
- Move COPYING to license section
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Oct 15 2021 Johannes Segitz <jsegitz@suse.com>
- Drop ProtectClock hardening, can cause issues if other device acceess is needed
* Wed Sep 22 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * hp-drive-guard.service
* Mon Sep 11 2017 fcrozat@suse.com
- Fix spelling of SUSE and replace old email address.
* Wed Mar 15 2017 dimstar@opensuse.org
- Correctly install the systemd service as a .service file (not
  .spec)
- Drop the sysV script on systemd setups
- Only call insserv on sysV systems.
* Fri Nov  9 2012 tiwai@suse.de
- Add systemd unit file
* Fri Jul 29 2011 tiwai@suse.de
- Convert to new polkit-1 (bnc#708992)
- Use gtk3 for FACTORY
* Tue Jun 28 2011 tiwai@suse.de
- Fix build with new libnotify on FACTORY
* Tue Sep 14 2010 tiwai@suse.de
- fix misc compile warnings due to wrong printf format and unused
  variables / functions
* Thu Sep  2 2010 tiwai@suse.de
- fix build with debuginfo (filelist fixed)
- removed unnecessary post and prereq
* Thu Sep  2 2010 tiwai@suse.de
- add missing prereq for insserv
- don't activate daemon as default (bnc#633806)
* Wed Sep  1 2010 tiwai@suse.de
- Initial version for SLED11-SP1-Update: verion 0.3.12, including
  translations (bnc#633806)
